Investigation and Optimization of StringDeduplication with Custom Heuristic in Different Versions of the JVM

Memory optimization in Java applications is essential for performance and scalability. This paper investigates the efficiency of the StringDeduplication parameter in JVM versions 11, 17, and 21, using a Web Crawler developed in Spring Boot. The results show that the efficiency of StringDeduplication decreased from 34.3% deduplication in version 11 to 3.4% in version 21, with an increase in deduplication time from 1,264 ms to 3,439 ms. To mitigate this problem, a custom solution in C was developed for JVM version 21, which increased deduplication to 31.1% and saved 110.2 MB of memory. The main scientific contribution of this work is the identification of the loss of efficiency of StringDeduplication in the latest JVM versions and the proposal of a custom solution that improves string deduplication, offering a viable alternative for developers and software engineers.

Authors

Institutions

Publication Details

Journal
IEEE Latin America Transactions
Published
2024-12-19
DOI
https://doi.org/10.1109/tla.2025.10810397
Citations
1
Primary Topic
Natural Language Processing Techniques
Type
article
Field-Weighted Citation Impact
0.35
Controls
|||
ALL TIME
JAN
FEB
MAR
APR
MAY
JUN
JUL
AUG
SEP
OCT
article

Investigation and Optimization of StringDeduplication with Custom Heuristic in Different Versions of the JVM

Anubis Graciela de Moraes Rossetto, Darlan Noetzold, Valderi Reis Quietinho Leithardt, Jorge Luís Victória Barbosa
1 citations
IEEE Latin America Transactions
Natural Language Processing Techniques
0.35
article

Investigation and Optimization of StringDeduplication with Custom Heuristic in Different Versions of the JVM

Anubis Graciela de Moraes Rossetto, Darlan Noetzold, Valderi Reis Quietinho Leithardt, Jorge Luís Victória Barbosa
article en
1 citations

Abstract

Memory optimization in Java applications is essential for performance and scalability. This paper investigates the efficiency of the StringDeduplication parameter in JVM versions 11, 17, and 21, using a Web Crawler developed in Spring Boot. The results show that the efficiency of StringDeduplication decreased from 34.3% deduplication in version 11 to 3.4% in version 21, with an increase in deduplication time from 1,264 ms to 3,439 ms. To mitigate this problem, a custom solution in C was developed for JVM version 21, which increased deduplication to 31.1% and saved 110.2 MB of memory. The main scientific contribution of this work is the identification of the loss of efficiency of StringDeduplication in the latest JVM versions and the proposal of a custom solution that improves string deduplication, offering a viable alternative for developers and software engineers.

IEEE Latin America TransactionsVol. 23(1)
Universidade Politécnica de Lisboa (PT), Instituto Federal Sul-rio-grandense (BR), Universidade do Vale do Rio dos Sinos (BR)
Openalex Percentile: Top 30%
Natural Language Processing Techniques
0.35
AI Navigator

Ask Laika to Summarize, Analyze, and Connect papers live on the map.

Summarize Papers & Methodologies

Extract key findings, datasets, and comparative methods across publications.

Benchmark Rankings & Visual Analytics

Rank top research institutions, authors, funders, topics, and journals by Field-Weighted Citation Impact (FWCI) and paper volume with instant charts.

Connect Distant Disciplines

Bridge topological clusters on the map to find hidden collaborative intersections.